*-------------------------------------------------------------------------------------------------------------------------------------;

* CIS - Community Innovation Survey 2008 - Data without Boundaries (Work Package 5);

* This routine converts CIS 2008 Italy data formatted in CSV into SAS7BDAT ;
* Checked for the July 2013 release of the CIS, as provided by Eurostat. ;

* Version 1 of the routine, March 2015;
* SAS 9.3;

* University of Ljubljana, Social Science Data Archives, partners of Data without Boundaries project;
* Sebastian Kocar;
* http://www.adp.fdv.uni-lj.si/;
* Contact: arhiv.podatkov@fdv.uni-lj.si;
*
* This SAS code is protected under the creative commons license. ;

*-------------------------------------------------------------------------------------------------------------------------------------;


* --- CONFIGURATION SECTION - START ---                                          ;


* The following command should contain the complete path and                     ;
* name of the .csv file to be read (e.g. "C:/CIS2008/Data/ALL.csv")              ;
* Change CSV_DATA_PATH to your filename, below                                   ;

FILENAME csvpath "CSV_DATA_PATH";


* The following command should contain the complete path of the                  ;
* directory where the setup file will be saved (e.g. "C:/CIS2008/Data")          ;
* Change SAS_DATA_FOLDER to your directory name, below                           ;

LIBNAME dirout "SAS_DATA_FOLDER";


* The following command should contain the name of the output SAS file only      ;
* (without quotes, and without the .sas7bdat extension)                          ;
* Change SAS_FILE_NAME to your output file name, below                           ;

%LET sasfile=SAS_FILE_NAME;


* --- CONFIGURATION SECTION -  END ---                                           ;

* ------------------------------------------------------------------------------ ;



* There should be nothing to change below this line;
* ------------------------------------------------------------------------------ ;



* --- Read the raw data file ---                                                 ;

DATA sasimport;

INFILE csvpath
       DLM=","
       FIRSTOBS=2
       DSD
       TRUNCOVER
       LRECL=512
       ;

INPUT  ID
       NUTS $
       NACE $
       GP
       HO
       MARLOC
       MARNAT
       MAREUR
       MAROTH
       LARMAR $
       INPDGD
       INPDSV
       INPDTW
       NEWMKT
       NEWFRM
       TURNMAR
       TURNIN
       TURNUNG
       INPSPD
       INPSLG
       INPSSU
       INPCSW
       INPSNM
       INABA
       INONG
       RRDIN
       RDENG
       RRDEX
       RMAC
       ROEK
       RTR
       RMAR
       RPRE
       RRDINX
       RRDEXX
       RMACX
       ROEKX
       RTRX
       RPREX
       RMARX
       RTOT
       FUNLOC
       FUNGMT
       FUNEU
       FUNRTD
       SENTG
       SSUP
       SCLI
       SCOM
       SINS
       SUNI
       SGMT
       SCON
       SJOU
       SPRO
       CO
       CO11
       CO12
       CO13
       CO14
       CO15
       CO21
       CO22
       CO23
       CO24
       CO25
       CO31
       CO32
       CO33
       CO34
       CO35
       CO41
       CO42
       CO43
       CO44
       CO45
       CO51
       CO52
       CO53
       CO54
       CO55
       CO61
       CO62
       CO63
       CO64
       CO65
       CO71
       CO72
       CO73
       CO74
       CO75
       PMOS $
       ORANGE
       OREPL
       OENMK
       OIMKS
       OQUA
       OFLEX
       OCAP
       OHES
       OLBR
       ORGBUP
       ORGWKP
       ORGEXR
       ORORED
       OROABL
       OROQUA
       ORORCO
       OROCIN
       MKTDGP
       MKTPDP
       MKTPDL
       MKTPRI
       OMKTS
       OMKTCG
       OMKTGM
       ECOMAT
       ECOEN
       ECOCO
       ECOSUB
       ECOPOL
       ECOREC
       ECOENU
       ECOPOS
       ECOREA
       ENREG
       ENREGF
       ENGRA
       ENDEM
       ENAGR
       ENVID
       TURN06
       TURN08
       EMP06 $
       EMP08 $
       WEIGHT
       WEIGHTNR
       ;
RUN;

* ------------------------------------------------------------------------------ ;


* --- Recode string variables which have labels, to numeric variables ---        ;

DATA sasimport;

    SET sasimport;

    IF (LARMAR = 'A') THEN TEMPVAR = 1;
    IF (LARMAR = 'B') THEN TEMPVAR = 2;
    IF (LARMAR = 'C') THEN TEMPVAR = 3;
    IF (LARMAR = 'D') THEN TEMPVAR = 4;

RUN;

DATA sasimport;

    SET sasimport;

    DROP LARMAR;
    RENAME TEMPVAR = LARMAR;

RUN;

DATA sasimport;

    SET sasimport;

    IF (PMOS = 'A') THEN TEMPVAR = 1;
    IF (PMOS = 'B') THEN TEMPVAR = 2;
    IF (PMOS = 'C') THEN TEMPVAR = 3;
    IF (PMOS = 'D') THEN TEMPVAR = 4;
    IF (PMOS = 'E') THEN TEMPVAR = 5;
    IF (PMOS = 'F') THEN TEMPVAR = 6;
    IF (PMOS = 'G') THEN TEMPVAR = 7;

RUN;

DATA sasimport;

    SET sasimport;

    DROP PMOS;
    RENAME TEMPVAR = PMOS;

RUN;

DATA sasimport;

    SET sasimport;

    IF (nace = 'B') THEN TEMPVAR = 1;
    IF (nace = '10') THEN TEMPVAR = 2;
    IF (nace = '12-No') THEN TEMPVAR = 3;
    IF (nace = '13') THEN TEMPVAR = 4;
    IF (nace = '14') THEN TEMPVAR = 5;
    IF (nace = '15') THEN TEMPVAR = 6;
    IF (nace = '16') THEN TEMPVAR = 7;
    IF (nace = '17') THEN TEMPVAR = 8;
    IF (nace = '18') THEN TEMPVAR = 9;
    IF (nace = '19') THEN TEMPVAR = 10;
    IF (nace = '20') THEN TEMPVAR = 11;
    IF (nace = '21') THEN TEMPVAR = 12;
    IF (nace = '22') THEN TEMPVAR = 13;
    IF (nace = '23') THEN TEMPVAR = 14;
    IF (nace = '24') THEN TEMPVAR = 15;
    IF (nace = '25') THEN TEMPVAR = 16;
    IF (nace = '26') THEN TEMPVAR = 17;
    IF (nace = '27') THEN TEMPVAR = 18;
    IF (nace = '28') THEN TEMPVAR = 19;
    IF (nace = '29') THEN TEMPVAR = 20;
    IF (nace = '30') THEN TEMPVAR = 21;
    IF (nace = '31') THEN TEMPVAR = 22;
    IF (nace = '32') THEN TEMPVAR = 23;
    IF (nace = '33') THEN TEMPVAR = 24;
    IF (nace = '35') THEN TEMPVAR = 25;
    IF (nace = '36') THEN TEMPVAR = 26;
    IF (nace = '37') THEN TEMPVAR = 27;
    IF (nace = '38-39') THEN TEMPVAR = 28;
    IF (nace = '41') THEN TEMPVAR = 29;
    IF (nace = '42') THEN TEMPVAR = 30;
    IF (nace = '43') THEN TEMPVAR = 31;
    IF (nace = '45') THEN TEMPVAR = 32;
    IF (nace = '46') THEN TEMPVAR = 33;
    IF (nace = '47') THEN TEMPVAR = 34;
    IF (nace = '49') THEN TEMPVAR = 35;
    IF (nace = '50') THEN TEMPVAR = 36;
    IF (nace = '51') THEN TEMPVAR = 37;
    IF (nace = '52') THEN TEMPVAR = 38;
    IF (nace = '53') THEN TEMPVAR = 39;
    IF (nace = '55') THEN TEMPVAR = 40;
    IF (nace = '56') THEN TEMPVAR = 41;
    IF (nace = '58') THEN TEMPVAR = 42;
    IF (nace = '59') THEN TEMPVAR = 43;
    IF (nace = '61') THEN TEMPVAR = 44;
    IF (nace = '62') THEN TEMPVAR = 45;
    IF (nace = '63') THEN TEMPVAR = 46;
    IF (nace = '64') THEN TEMPVAR = 47;
    IF (nace = '65') THEN TEMPVAR = 48;
    IF (nace = '66') THEN TEMPVAR = 49;
    IF (nace = '68') THEN TEMPVAR = 50;
    IF (nace = '71') THEN TEMPVAR = 51;
    IF (nace = '72') THEN TEMPVAR = 52;
    IF (nace = '77') THEN TEMPVAR = 53;

RUN;

DATA sasimport;

    SET sasimport;

    DROP nace;
    RENAME TEMPVAR = nace;

RUN;

DATA sasimport;

    SET sasimport;

    IF (emp06 = '10_49') THEN TEMPVAR = 1;
    IF (emp06 = '50-249') THEN TEMPVAR = 2;
    IF (emp06 = '250+') THEN TEMPVAR = 3;
    IF (emp06 = '50+') THEN TEMPVAR = 4;
    IF (emp06 = 'ALL') THEN TEMPVAR = 5;

RUN;

DATA sasimport;

    SET sasimport;

    DROP emp06;
    RENAME TEMPVAR = emp06;

RUN;

DATA sasimport;

    SET sasimport;

    IF (emp08 = '10_49') THEN TEMPVAR = 1;
    IF (emp08 = '50-249') THEN TEMPVAR = 2;
    IF (emp08 = '250+') THEN TEMPVAR = 3;
    IF (emp08 = '50+') THEN TEMPVAR = 4;
    IF (emp08 = 'ALL') THEN TEMPVAR = 5;

RUN;

DATA sasimport;

    SET sasimport;

    DROP emp08;
    RENAME TEMPVAR = emp08;

RUN;

* ------------------------------------------------------------------------------ ;


* --- Reorder the variables in their original positions ---                      ;

DATA sasimport;

    RETAIN ID GP MARLOC MARNAT MAREUR MAROTH LARMAR INPDGD INPDSV INPDTW NEWMKT
           NEWFRM TURNMAR TURNIN TURNUNG INPSPD INPSLG INPSSU INPCSW INPSNM
           INABA INONG RRDIN RDENG RRDEX RMAC ROEK RTR RMAR RPRE FUNLOC
           FUNGMT FUNEU FUNRTD SENTG SSUP SCLI SCOM SINS SUNI SGMT SCON
           SJOU SPRO CO CO11 CO12 CO13 CO14 CO15 CO21 CO22 CO23 CO24 CO25
           CO31 CO32 CO33 CO34 CO35 CO41 CO42 CO43 CO44 CO45 CO51 CO52
           CO53 CO54 CO55 CO61 CO62 CO63 CO64 CO65 CO71 CO72 CO73 CO74
           CO75 PMOS ORANGE OREPL OENMK OIMKS OQUA OFLEX OCAP OHES OLBR
           ORGBUP ORGWKP ORGEXR ORORED OROABL OROQUA ORORCO OROCIN MKTDGP
           MKTPDP MKTPDL MKTPRI OMKTS OMKTCG OMKTGM ECOMAT ECOEN ECOCO ECOSUB
           ECOPOL ECOREC ECOENU ECOPOS ECOREA ENREG ENREGF ENGRA ENDEM ENAGR
           ENVID WEIGHT NUTS NACE HO RRDINX RRDEXX RMACX ROEKX RTRX RPREX
           RMARX RTOT TURN06 TURN08 EMP06 EMP08 WEIGHTNR;

    SET sasimport;

RUN;

* ------------------------------------------------------------------------------ ;


* --- Add variable labels ---                                                    ;

DATA sasimport;

    SET sasimport;

    LABEL ID       = "Name of the enterprise";
    LABEL GP       = "Enterprise part of a group";
    LABEL MARLOC   = "Local/regional market (within country)";
    LABEL MARNAT   = "National market (other regions of country)";
    LABEL MAREUR   = "Other EU/EFTA/CC market";
    LABEL MAROTH   = "All other countries";
    LABEL LARMAR   = "Largest market in terms of turnover between 2006 and 2008";
    LABEL INPDGD   = "Introduced onto the market a new or significantly improved good";
    LABEL INPDSV   = "Introduced onto the market a new or significantly improved service";
    LABEL INPDTW   = "Who mainly developed these products";
    LABEL NEWMKT   = "Did the enterprise introduce a product new to the market";
    LABEL NEWFRM   = "Did the enterprise introduce a product new to the firm";
    LABEL TURNMAR  = "% of turnover in new or improved products introduced during 2006-2008 that were new to the market";
    LABEL TURNIN   = "% of turnover in new or improved products introduced during 2006-2008 that were only new to the firm";
    LABEL TURNUNG  = "% of turnover in  unchanged or marginally modified products during 2006-2008";
    LABEL INPSPD   = "Introduced onto the market a new or significantly improved method of production";
    LABEL INPSLG   = "Introduced onto the market a new or significantly improved logistic, delivery or distribution system";
    LABEL INPSSU   = "Introduced onto the market a new or significantly improved supporting activities";
    LABEL INPCSW   = "Who mainly developed these processes";
    LABEL INPSNM   = "Were any of your process innovations introduced between 2006 and 2008 new to your market";
    LABEL INABA    = "Abandoned or suspended before completion";
    LABEL INONG    = "Still ongoing at the end of the 2008";
    LABEL RRDIN    = "Engagement in intramural R&D";
    LABEL RDENG    = "Type of engagement in R&D";
    LABEL RRDEX    = "Engagement in extramural R&D";
    LABEL RMAC     = "Engagement in acquisition of machinery";
    LABEL ROEK     = "Engagement in acquisition of external knowledge";
    LABEL RTR      = "Engagement in training for innovative activities";
    LABEL RMAR     = "Engagement in market introduction of innovation";
    LABEL RPRE     = "Engagement in other preparation";
    LABEL FUNLOC   = "Public funding from local or regional authorities";
    LABEL FUNGMT   = "Public funding from central government";
    LABEL FUNEU    = "Public funding from the EU";
    LABEL FUNRTD   = "Funding from EU's 4th, 5th, 6th or 7th Framework Programme for RTD";
    LABEL SENTG    = "Sources from within the enterprise";
    LABEL SSUP     = "Sources from Suppliers of equipment, materials, etc.";
    LABEL SCLI     = "Sources from Clients or customers";
    LABEL SCOM     = "Sources from Competitors and other enterprises of same industry";
    LABEL SINS     = "Sources from consultants, commercial labs or private R&D institutes";
    LABEL SUNI     = "Sources from Universities or other higher education institutes";
    LABEL SGMT     = "Sources from Government or public research institutes";
    LABEL SCON     = "Sources from professional conferences, trade fairs, meetings";
    LABEL SJOU     = "Sources from Scientific journals, trade/scientific publications";
    LABEL SPRO     = "Sources from Professional and industry associations";
    LABEL CO       = "Cooperation arrangements on innovation activities";
    LABEL CO11     = "Other enterprises within enterprise group : National";
    LABEL CO12     = "Other enterprises within enterprise group : EU/EFTA/EU-CC";
    LABEL CO13     = "Other enterprises within enterprise group : US";
    LABEL CO14     = "Other enterprises within enterprise group : China or India";
    LABEL CO15     = "Other enterprises within enterprise group : Other countries";
    LABEL CO21     = "Suppliers of equipment, etc. : National";
    LABEL CO22     = "Suppliers of equipment, etc. : EU/EFTA/EU-CC";
    LABEL CO23     = "Suppliers of equipment, etc. : US";
    LABEL CO24     = "Suppliers of equipment, etc. : China or India";
    LABEL CO25     = "Suppliers of equipment, etc. :  Other countries";
    LABEL CO31     = "Clients or customers : National";
    LABEL CO32     = "Clients or customers : EU/EFTA/EU-CC";
    LABEL CO33     = "Clients or customers : US";
    LABEL CO34     = "Clients or customers : China or India";
    LABEL CO35     = "Clients or customers : Other countries";
    LABEL CO41     = "Competitors or other firms  : National";
    LABEL CO42     = "Competitors or other firms  : EU/EFTA/EU-CC";
    LABEL CO43     = "Competitors or other firms  : US";
    LABEL CO44     = "Competitors or other firms  : China or India";
    LABEL CO45     = "Competitors or other firms  : Other countries";
    LABEL CO51     = "Consultants, commercial labs, private R&D institutes : National";
    LABEL CO52     = "Consultants, commercial labs, private R&D institutes : EU/EFTA/EU-CC";
    LABEL CO53     = "Consultants, commercial labs, private R&D institutes : US";
    LABEL CO54     = "Consultants, commercial labs, private R&D institutes : China or India";
    LABEL CO55     = "Consultants, commercial labs, private R&D institutes : Other countries";
    LABEL CO61     = "Universities or other  : National";
    LABEL CO62     = "Universities or other  : EU/EFTA/EU-CC";
    LABEL CO63     = "Universities or other  : US";
    LABEL CO64     = "Universities or other  : China or India";
    LABEL CO65     = "Universities or other  : Other countries";
    LABEL CO71     = "Government or public research institutes: National";
    LABEL CO72     = "Government or public research institutes:  EU/EFTA/EU-CC";
    LABEL CO73     = "Government or public research institutes: US";
    LABEL CO74     = "Government or public research institutes: China or India";
    LABEL CO75     = "Government or public research institutes: Other countries";
    LABEL PMOS     = "Most important co-operation partner";
    LABEL ORANGE   = "Increased range of goods or services";
    LABEL OREPL    = "Replace outdated products or processes";
    LABEL OENMK    = "Enter new markets";
    LABEL OIMKS    = "Increase market share";
    LABEL OQUA     = "Improve quality of goods or services";
    LABEL OFLEX    = "Improve flexibility for producing goods or services";
    LABEL OCAP     = "Increase capacity for producing goods or services";
    LABEL OHES     = "Improve health and safety";
    LABEL OLBR     = "Reduce labour costs per unit output";
    LABEL ORGBUP   = "New business practices for organising work or procedures";
    LABEL ORGWKP   = "New methods of workplace organisation";
    LABEL ORGEXR   = "New methods of organising external relations";
    LABEL ORORED   = "Reduce time to respond to customer or supplier needs";
    LABEL OROABL   = "Improve ability to develop new products or processes";
    LABEL OROQUA   = "Improve quality of your goods or services";
    LABEL ORORCO   = "Reduce costs per unit output";
    LABEL OROCIN   = "Improved communication or information sharing";
    LABEL MKTDGP   = "Significant changes to the aesthetic design or packaging";
    LABEL MKTPDP   = "New media or techniques for product promotion";
    LABEL MKTPDL   = "New methods for product placement or sales channels";
    LABEL MKTPRI   = "New methods of pricing goods or services";
    LABEL OMKTS    = "Increase or maintain market share";
    LABEL OMKTCG   = "Introduce products to new customer groups";
    LABEL OMKTGM   = "Introduce products to new geographic markets";
    LABEL ECOMAT   = "Reduced material use per unit of output";
    LABEL ECOEN    = "Reduced energy use per unit of output";
    LABEL ECOCO    = "Reduced CO2 footprint (total CO2 production) by your enterprise";
    LABEL ECOSUB   = "Replaced materials with less polluting or hazardous substitutes";
    LABEL ECOPOL   = "Reduced soil, water, noise, or air pollution";
    LABEL ECOREC   = "Recycled waste, water, or materials";
    LABEL ECOENU   = "Reduced energy use";
    LABEL ECOPOS   = "Reduced air, water, soil or noise pollution";
    LABEL ECOREA   = "Improved recycling of product after use";
    LABEL ENREG    = "Existing environmental regulations or taxes on pollution";
    LABEL ENREGF   = "Environmental regulations or taxes that you expected to be introduced in the future";
    LABEL ENGRA    = "Availability of government grants, subsidies or other financial incentives for environmental innovation";
    LABEL ENDEM    = "Current or expected market demand from your customers for environmental innovations";
    LABEL ENAGR    = "Voluntary codes or agreements for environmental good practice within your sector";
    LABEL ENVID    = "Procedures in place to regularly identify and reduce enterprises environmental impacts";
    LABEL WEIGHT   = "Weight";
    LABEL NUTS     = "Country of enterprise";
    LABEL NACE     = "Main activity";
    LABEL HO       = "Country of head office";
    LABEL RRDINX   = "Expenditure in intramural R&D";
    LABEL RRDEXX   = "Purchase of extramural R&D";
    LABEL RMACX    = "Expenditure in acquisition of machinery";
    LABEL ROEKX    = "Expenditure in acquisition of external knowledge";
    LABEL RTRX     = "Expenditure in training";
    LABEL RPREX    = "Expenditure in other preparation";
    LABEL RMARX    = "Expenditure in market introduction of innovation";
    LABEL RTOT     = "Unknown weight variable, maybe based on nr. of employees?";
    LABEL TURN06   = "Total turnover in 2006";
    LABEL TURN08   = "Total turnover in 2008";
    LABEL EMP06    = "Total number of employees in 2006";
    LABEL EMP08    = "Total number of employees in 2008";
    LABEL WEIGHTNR = "Weights corrected for non-response bias";

RUN;

* ------------------------------------------------------------------------------ ;


* --- Create value labels groups ---                                             ;

PROC FORMAT;

VALUE LABELS_1_GROUP
      0="No"
      1="Yes";

VALUE LABELS_2_GROUP
      1="Local/regional within [your country]"
      2="National (other regions of [your country])"
      3="Other European Union (EU), EFTA, or EU candidate countries"
      4="All other countries";

VALUE LABELS_3_GROUP
      1="Mainly by the enterprise or enterprise group"
      2="In cooperation with other enterprises or institutions"
      3="Mainly other enterprises or institutions";

VALUE LABELS_4_GROUP
      0="No"
      1="Yes"
      2="Do not know";

VALUE LABELS_5_GROUP
      1="continuously"
      2="occasionally";

VALUE LABELS_6_GROUP
      0="Not used"
      1="Low"
      2="Med"
      3="High";

VALUE LABELS_7_GROUP
      1="Other enterprises within enterprise group"
      2="Suppliers of equipment, etc"
      3="Clients or customers"
      4="Competitors or other firms"
      5="Consultants, commercial labs, private R&D institutes"
      6="Universities or other"
      7="Government or public research institutes";

VALUE LABELS_8_GROUP
      0="Not relevant"
      1="Low"
      2="Med"
      3="High";

VALUE LABELS_9_GROUP
      0="No"
      1="Yes: Implemented before January 2006"
      2="Yes: Implemented or significantly improved after January 2006"
      3="Yes for both before and after January 2006";

VALUE LABELS_10_GROUP
      1="Mining and quarrying"
      2="Manufacture of food products"
      3="Manufacture of tobacco products"
      4="Manufacture of textiles"
      5="Manufacture of wearing apparel"
      6="Manufacture of leather and related products"
      7="Manufacture of wood, of products of wood, cork, except furniture; manufacture of articles of straw, plaiting materials"
      8="Manufacture of paper and paper products"
      9="Printing and reproduction of recorded media"
      10="Manufacture of coke and refined petroleum products"
      11="Manufacture of chemicals and chemical products"
      12="Manufacture of basic pharmaceutical products and pharmaceutical preparations"
      13="Manufacture of rubber and plastic products"
      14="Manufacture of other non-metallic mineral products"
      15="Manufacture of basic metals"
      16="Manufacture of fabricated metal products, except machinery and equipment"
      17="Manufacture of computer, electronic and optical products"
      18="Manufacture of electrical equipment"
      19="Manufacture of machinery and equipment n.e.c."
      20="Manufacture of motor vehicles, trailers and semi-trailers"
      21="Manufacture of other transport equipment"
      22="Manufacture of furniture"
      23="Other manufacturing"
      24="Repair and installation of machinery and equipment"
      25="Electricity, gas, steam and air conditioning supply"
      26="Water collection, treatment and supply"
      27="Sewerage"
      28="Waste management and remediation activities"
      29="Construction of buildings"
      30="Civil engineering"
      31="Specialised construction activities"
      32="Wholesale and retail trade and repair of motor vehicles and motorcycles"
      33="Wholesale trade, except of motor vehicles and motorcycles"
      34="Retail trade, except of motor vehicles and motorcycles"
      35="Land transport and transport via pipelines"
      36="Water transport"
      37="Air transport"
      38="Warehousing and support activities for transportation"
      39="Postal and courier activities"
      40="Accommodation"
      41="Food and beverage service activities"
      42="Publishing activities"
      43="Motion picture, video and television programme production, sound recording and music publishing activities"
      44="Telecommunications"
      45="Computer programming, consultancy and related activities"
      46="Information service activities"
      47="Financial service activities, except insurance and pension funding"
      48="Insurance, reinsurance and pension funding, except compulsory social security"
      49="Activities auxiliary to financial services and insurance activities"
      50="Real estate activities"
      51="Architectural and engineering activities; technical testing and analysis"
      52="Scientific research and development"
      53="Rental and leasing activities";

VALUE LABELS_11_GROUP
      0="No answer"
      1="Home country"
      2="EU, EFTA, CC"
      3="rest of world";

VALUE LABELS_12_GROUP
      1="10-49"
      2="50-249"
      3="250+"
      4="50+ (only for NACE 45, 65, 66, 68, 72, 77 and B)"
      5="ALL (only for NACE 53)";

RUN;

* ------------------------------------------------------------------------------ ;


* --- Format variables with value labels ---                                     ;

DATA sasimport;

    SET sasimport;

    FORMAT
    GP       LABELS_1_GROUP.
    MARLOC   LABELS_1_GROUP.
    MARNAT   LABELS_1_GROUP.
    MAREUR   LABELS_1_GROUP.
    MAROTH   LABELS_1_GROUP.
    INPDGD   LABELS_1_GROUP.
    INPDSV   LABELS_1_GROUP.
    NEWMKT   LABELS_1_GROUP.
    NEWFRM   LABELS_1_GROUP.
    INPSPD   LABELS_1_GROUP.
    INPSLG   LABELS_1_GROUP.
    INPSSU   LABELS_1_GROUP.
    INABA    LABELS_1_GROUP.
    INONG    LABELS_1_GROUP.
    RRDIN    LABELS_1_GROUP.
    RRDEX    LABELS_1_GROUP.
    RMAC     LABELS_1_GROUP.
    ROEK     LABELS_1_GROUP.
    RTR      LABELS_1_GROUP.
    RMAR     LABELS_1_GROUP.
    RPRE     LABELS_1_GROUP.
    FUNLOC   LABELS_1_GROUP.
    FUNGMT   LABELS_1_GROUP.
    FUNEU    LABELS_1_GROUP.
    FUNRTD   LABELS_1_GROUP.
    CO       LABELS_1_GROUP.
    CO11     LABELS_1_GROUP.
    CO12     LABELS_1_GROUP.
    CO13     LABELS_1_GROUP.
    CO14     LABELS_1_GROUP.
    CO15     LABELS_1_GROUP.
    CO21     LABELS_1_GROUP.
    CO22     LABELS_1_GROUP.
    CO23     LABELS_1_GROUP.
    CO24     LABELS_1_GROUP.
    CO25     LABELS_1_GROUP.
    CO31     LABELS_1_GROUP.
    CO32     LABELS_1_GROUP.
    CO33     LABELS_1_GROUP.
    CO34     LABELS_1_GROUP.
    CO35     LABELS_1_GROUP.
    CO41     LABELS_1_GROUP.
    CO42     LABELS_1_GROUP.
    CO43     LABELS_1_GROUP.
    CO44     LABELS_1_GROUP.
    CO45     LABELS_1_GROUP.
    CO51     LABELS_1_GROUP.
    CO52     LABELS_1_GROUP.
    CO53     LABELS_1_GROUP.
    CO54     LABELS_1_GROUP.
    CO55     LABELS_1_GROUP.
    CO61     LABELS_1_GROUP.
    CO62     LABELS_1_GROUP.
    CO63     LABELS_1_GROUP.
    CO64     LABELS_1_GROUP.
    CO65     LABELS_1_GROUP.
    CO71     LABELS_1_GROUP.
    CO72     LABELS_1_GROUP.
    CO73     LABELS_1_GROUP.
    CO74     LABELS_1_GROUP.
    CO75     LABELS_1_GROUP.
    ORGBUP   LABELS_1_GROUP.
    ORGWKP   LABELS_1_GROUP.
    ORGEXR   LABELS_1_GROUP.
    MKTDGP   LABELS_1_GROUP.
    MKTPDP   LABELS_1_GROUP.
    MKTPDL   LABELS_1_GROUP.
    MKTPRI   LABELS_1_GROUP.
    ECOMAT   LABELS_1_GROUP.
    ECOEN    LABELS_1_GROUP.
    ECOCO    LABELS_1_GROUP.
    ECOSUB   LABELS_1_GROUP.
    ECOPOL   LABELS_1_GROUP.
    ECOREC   LABELS_1_GROUP.
    ECOENU   LABELS_1_GROUP.
    ECOPOS   LABELS_1_GROUP.
    ECOREA   LABELS_1_GROUP.
    ENREG    LABELS_1_GROUP.
    ENREGF   LABELS_1_GROUP.
    ENGRA    LABELS_1_GROUP.
    ENDEM    LABELS_1_GROUP.
    ENAGR    LABELS_1_GROUP.
    LARMAR   LABELS_2_GROUP.
    INPDTW   LABELS_3_GROUP.
    INPCSW   LABELS_3_GROUP.
    INPSNM   LABELS_4_GROUP.
    RDENG    LABELS_5_GROUP.
    SENTG    LABELS_6_GROUP.
    SSUP     LABELS_6_GROUP.
    SCLI     LABELS_6_GROUP.
    SCOM     LABELS_6_GROUP.
    SINS     LABELS_6_GROUP.
    SUNI     LABELS_6_GROUP.
    SGMT     LABELS_6_GROUP.
    SCON     LABELS_6_GROUP.
    SJOU     LABELS_6_GROUP.
    SPRO     LABELS_6_GROUP.
    PMOS     LABELS_7_GROUP.
    ORANGE   LABELS_8_GROUP.
    OREPL    LABELS_8_GROUP.
    OENMK    LABELS_8_GROUP.
    OIMKS    LABELS_8_GROUP.
    OQUA     LABELS_8_GROUP.
    OFLEX    LABELS_8_GROUP.
    OCAP     LABELS_8_GROUP.
    OHES     LABELS_8_GROUP.
    OLBR     LABELS_8_GROUP.
    ORORED   LABELS_8_GROUP.
    OROABL   LABELS_8_GROUP.
    OROQUA   LABELS_8_GROUP.
    ORORCO   LABELS_8_GROUP.
    OROCIN   LABELS_8_GROUP.
    OMKTS    LABELS_8_GROUP.
    OMKTCG   LABELS_8_GROUP.
    OMKTGM   LABELS_8_GROUP.
    ENVID    LABELS_9_GROUP.
    NACE     LABELS_10_GROUP.
    HO       LABELS_11_GROUP.
    EMP06    LABELS_12_GROUP.
    EMP08    LABELS_12_GROUP.
    ;

RUN;

* ------------------------------------------------------------------------------ ;


* --- Save data to a sas type file ---                                           ;

DATA dirout.&sasfile;

    SET sasimport;

RUN;
